pub struct ForgetParams {
pub fact_id: i64,
pub reason: String,
pub space: Option<String>,
}Fields
fact_id: i64Fact id to close (from memory_recall / memory_facts_about output)
reason: StringWhy this fact should be forgotten (recorded, never deleted)
space: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ForgetParams
impl<'de> Deserialize<'de> for ForgetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ForgetParams
impl JsonSchema for ForgetParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForgetParams
impl RefUnwindSafe for ForgetParams
impl Send for ForgetParams
impl Sync for ForgetParams
impl Unpin for ForgetParams
impl UnsafeUnpin for ForgetParams
impl UnwindSafe for ForgetParams