pub struct PendingParams {
pub limit: Option<usize>,
pub space: Option<String>,
}Fields
limit: Option<usize>Max episodes to return (1..=20)
space: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PendingParams
impl<'de> Deserialize<'de> for PendingParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PendingParams
impl JsonSchema for PendingParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PendingParams
impl RefUnwindSafe for PendingParams
impl Send for PendingParams
impl Sync for PendingParams
impl Unpin for PendingParams
impl UnsafeUnpin for PendingParams
impl UnwindSafe for PendingParams