pub struct StoreFactsParams {
pub episode_id: i64,
pub facts: Vec<SubmittedFact>,
pub space: Option<String>,
}Fields
episode_id: i64Episode id from memory_pending
facts: Vec<SubmittedFact>Extracted facts (max 50)
space: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for StoreFactsParams
impl<'de> Deserialize<'de> for StoreFactsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoreFactsParams
impl JsonSchema for StoreFactsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreFactsParams
impl RefUnwindSafe for StoreFactsParams
impl Send for StoreFactsParams
impl Sync for StoreFactsParams
impl Unpin for StoreFactsParams
impl UnsafeUnpin for StoreFactsParams
impl UnwindSafe for StoreFactsParams